==> aidlab_sdk-0.0.3.tar.gz: ios/Classes/AidlabSdkHandler.swift <==
//
//  AidlabSdkHandler.swift
//  AidlabSDK
//
//  Created by Szymon Gęsicki on 05/02/2021.
//  Copyright © 2020 Aidlab. All rights reserved.
//
import Flutter
import AidlabSDK

public class AidlabSdkHandler: PlatformAidlabSdk {
    
    private var aidlabSDKListener: PlatformAidlabSdkDelegate?
    private var aidlabHandler: AidlabHandler
    private var aidlabBluetoothManager: AidlabBluetoothManager
    
    init(aidlabHandler: AidlabHandler, aidlabBluetoothManager: AidlabBluetoothManager) {
        self.aidlabHandler = aidlabHandler
        self.aidlabBluetoothManager = aidlabBluetoothManager
    }
    
    func initial(binding: FlutterBinaryMessenger) {
        aidlabSDKListener = PlatformAidlabSdkDelegate(binaryMessenger: binding)
        PlatformAidlabSdkSetup(binding, self)
        aidlabBluetoothManager.listener = aidlabSDKListener
    }
    
    func release() {
        aidlabBluetoothManager.stopScan()
        aidlabBluetoothManager.listener = nil
    }
    
    public func scan(forDevices error: AutoreleasingUnsafeMutablePointer<FlutterError?>) {
        aidlabBluetoothManager.startScan()
    }
    
    public func stopDeviceScan(_ error: AutoreleasingUnsafeMutablePointer<FlutterError?>) {
        aidlabBluetoothManager.stopScan()
    }
    
    public func connect(_ input: ConnectRequest, error: AutoreleasingUnsafeMutablePointer<FlutterError?>) {
        aidlabBluetoothManager.stopScan()
        
        /// TODO throw exception
        guard let address = input.address else {
            print("Error: connect input = nil")
            return
        }
        
        guard let aidlab = aidlabBluetoothManager.addressToAidlab(address: address) else {
            print("Error: connect addressToAidlab")
            return
        }
        
        guard let rawSignals = input.signals?.data.toArray(type: Int32.self) else {
            print("Error: connect data to raw signals ")
            return
        }
        
        let signals = rawSignals.compactMap { Signal(rawValue: Int($0)) }
        aidlabBluetoothManager.connect(signals: signals, aidlab: aidlab, delegate: aidlabHandler)
    }
}

==> aidlab_sdk-0.0.15.tar.gz: ios/Classes/AidlabSdkHandler.swift <==
//
//  AidlabSdkHandler.swift
//  AidlabSDK
//
//  Created by Szymon Gęsicki on 05/02/2021.
//  Copyright © 2020 Aidlab. All rights reserved.
//
import Flutter
import AidlabSDK

public class AidlabSdkHandler: PlatformAidlabSdk {
    
    private var aidlabSDKListener: PlatformAidlabSdkDelegate?
    private var aidlabHandler: AidlabHandler
    private var aidlabBluetoothManager: AidlabBluetoothManager
    
    public func `init`(_ error: AutoreleasingUnsafeMutablePointer<FlutterError?>) {}
    
    init(aidlabHandler: AidlabHandler, aidlabBluetoothManager: AidlabBluetoothManager) {
        self.aidlabHandler = aidlabHandler
        self.aidlabBluetoothManager = aidlabBluetoothManager
    }
    
    func initial(binding: FlutterBinaryMessenger) {
        aidlabSDKListener = PlatformAidlabSdkDelegate(binaryMessenger: binding)
        PlatformAidlabSdkSetup(binding, self)
        aidlabBluetoothManager.listener = aidlabSDKListener
    }
    
    func release() {
        aidlabBluetoothManager.stopScan()
        aidlabBluetoothManager.listener = nil
    }
    
    public func scan(forDevices input: ScanModeRequest, error: AutoreleasingUnsafeMutablePointer<FlutterError?>) {
        
        guard let scanMode = input.mode else {
            print("Error: scanMode input = nil")
            return
        }
        aidlabBluetoothManager.startScan(scanMode: ScanMode(rawValue: Int(truncating: scanMode)) ?? .lowPower)
    }
    
    public func stopDeviceScan(_ error: AutoreleasingUnsafeMutablePointer<FlutterError?>) {
        aidlabBluetoothManager.stopScan()
    }
    
    public func connect(_ input: ConnectRequest, error: AutoreleasingUnsafeMutablePointer<FlutterError?>) {
        aidlabBluetoothManager.stopScan()
        
        /// TODO throw exception
        guard let address = input.address else {
            print("Error: connect input = nil")
            return
        }
        
        guard let aidlab = aidlabBluetoothManager.addressToAidlab(address: address) else {
            print("Error: connect addressToAidlab")
            return
        }
        
        guard let rawSignals = input.signals?.data.toArray(type: Int32.self) else {
            print("Error: connect data to raw signals ")
            return
        }
        
        let signals = rawSignals.compactMap { Signal(rawValue: Int($0)) }
        aidlabBluetoothManager.connect(signals: signals, aidlab: aidlab, delegate: aidlabHandler)
    }
}
